@@ -341,8 +341,8 @@ class PSO_new(object):
 
 		self.numberofparticles = n
 		
-		if not self.ParallelFitness:
-			self.UpdateCalculatedFitness()		# experimental
+		# if not self.ParallelFitness:
+		self.UpdateCalculatedFitness()		# experimental
 
 		vectorFirstFitnesses = [ x.CalculatedFitness for x in self.Solutions ]
 		self.EstimatedWorstFitness = max(vectorFirstFitnesses)
@@ -843,7 +843,7 @@ class FuzzyPSO(PSO_new):
 
 
 
-	def set_parallel_fitness(self, fitness, arguments=None, skip_test=False):
+	def set_parallel_fitness(self, fitness, arguments=None, skip_test=True):
 		print ( " * Parallel fitness requested")
 		if skip_test:
 			self.FITNESS = fitness
@@ -973,11 +973,17 @@ class FuzzyPSO(PSO_new):
 			and then update the settings of each particle.
 		"""
 
+		# parallel evaluation
 		if self.ParallelFitness:
 			if self._discrete_cases is not None: raise NotImplementedError() # TODO
 			ripop = list(map(lambda x: x.X, self.Solutions))
 			# TODO: make parallel version of discrete case
-			all_fitness = self.FITNESS(ripop, self._FITNESS_ARGS)
+			if self._FITNESS_ARGS is not None:
+				all_fitness = self.FITNESS(ripop, self._FITNESS_ARGS)
+			else:
+				all_fitness = self.FITNESS(ripop)
+
+		# sequential evaluation
 		else:
 			all_fitness = []
 			for s in self.Solutions:
